/*
 * file CcRegistryRegion.java
 * 
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM 
 *
 * com.ibm.rational.wvcm.stp.cc.CcRegistryRegion
 *
 *  Copyright IBM Corporation 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.rational.wvcm.stp.cc;

import static com.ibm.rational.wvcm.stpex.StpExBase.PROPERTY_NAMESPACE;

import javax.wvcm.ResourceList;
import javax.wvcm.WvcmException;
import javax.wvcm.PropertyNameList.PropertyName;

import com.ibm.rational.wvcm.stpex.StpExBase;

/**
 * <p>
 * A proxy for a ClearCase registry region. 
 * </p>
 * <p>
 * A registry region is a tag namespace shared by a subset of registry clients. 
 * The Rational ClearCase registry supports only a single region. With the Rational ClearCase registry, 
 * you can create multiple regions. VOB and view tags in a Rational ClearCase registry include the 
 * name of the registry region in which the tag is visible. Each Rational ClearCase client is a 
 * member of a single registry region and can access only those VOBs and views whose tags are 
 * visible in that region.
 * </p>
 * <p>
 * For more information about registry regions, see the ClearCase "Administrator's Guide"
 * manual, and the cleartool man pages "lsregion" and "mkregion".
 * </p>
 */

public interface CcRegistryRegion extends CcResource {

    /** List of VOB tags in this registry region as CcVobTag instances */
    PropertyName<ResourceList<CcVobTag>> VOB_TAG_LIST =
        new PropertyName<ResourceList<CcVobTag>>(PROPERTY_NAMESPACE,
                                               "vob-tag-list");
    
    /**
     * Returns the value of this proxy's {@link #VOB_TAG_LIST} property.
     * 
     * @return list of VOB tags registered in the region
     * @throws WvcmException
     *             if this proxy doesn't define a value for this property.
     */
    ResourceList<CcVobTag> getVobTagList() throws WvcmException;

    /** List of view tags in this registry region as CcViewTag instances */
    PropertyName<ResourceList<CcViewTag>> VIEW_TAG_LIST =
        new PropertyName<ResourceList<CcViewTag>>(PROPERTY_NAMESPACE,
                                                  "view-tag-list");

    /**
     * Returns the value of this proxy's {@link #VIEW_TAG_LIST} property.
     * 
     * @return list of view tags registered in the region
     * @throws WvcmException
     *             if this proxy doesn't define a value for this property.
     */
    ResourceList<CcViewTag> getViewTagList() throws WvcmException;
}
